@@ -162,11 +162,8 @@ class getter_seleniumTest(baseGetter):
             #html = self.wDriver.page_source.encode('utf-8')
             #html = element[0].parent.page_source
             html = element.parent.page_source
-            #bsSrc = BeautifulSoup(html, 'html.parser')
             bsSrc = BeautifulSoup(html, 'lxml')
             
-            print(html)
-            
             # スクレイピング結果から改行ｺｰﾄﾞを除去
             [tag.extract() for tag in bsSrc(string='\n')]
 
