@@ -1,6 +1,7 @@
 import datetime
 import pandas as pd
 import numpy as np
+import gc
 import LibHanger.Library.uwLogger as Logger
 from bs4 import BeautifulSoup
 from pandas.core.frame import DataFrame
@@ -69,6 +70,8 @@ class getter_trnDayStockPrice(baseGetter):
                 kwargs['brandCd'] = rsMstBrand.fields(mstbrand.brandcd.key).value
                 df = self.getStockDataToDataFrame(**kwargs)
                 Logger.logging.info('<<<<<< Finished Get TrnDayStockPrice Count={0}.'.format(len(df)))
+                del df
+                gc.collect()
                 # mem-check
                 self.cbCheckMem()
                 
@@ -344,7 +347,7 @@ class getter_trnDayStockPrice(baseGetter):
             
             # html解析
             html = element.parent.page_source
-            bsSrc = BeautifulSoup(html, 'html.parser')
+            bsSrc = BeautifulSoup(html, 'lxml')
 
             # スクレイピング結果から改行ｺｰﾄﾞを除去
             [tag.extract() for tag in bsSrc(string='\n')]
@@ -464,6 +467,10 @@ class getter_trnDayStockPrice(baseGetter):
                 # レコードセットマージ
                 bc.rsTrnDayStockPrice.merge(rsTrnDayStockPrice, False)
                 
+                # 使い終わったレコードセットを解放
+                del dfTrnDayStockPrice
+                del rsTrnDayStockPrice
+                
             # 戻り値を返す
             return rsTrnDayStockPrice.getDataFrame()
 
